Class: Aws::SignerData::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SignerData::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-signerdata/client.rb
Overview
An API client for SignerData. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SignerData::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_revocation_status(params = {}) ⇒ Types::GetRevocationStatusResponse
Retrieves the revocation status for a signed artifact by checking if the signing profile, job, or certificate has been revoked.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-signerdata/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
575 576 577 |
# File 'lib/aws-sdk-signerdata/client.rb', line 575 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
578 579 580 |
# File 'lib/aws-sdk-signerdata/client.rb', line 578 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 |
# File 'lib/aws-sdk-signerdata/client.rb', line 548 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SignerData') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-signerdata' context[:gem_version] = '1.3.0' Seahorse::Client::Request.new(handlers, context) end |
#get_revocation_status(params = {}) ⇒ Types::GetRevocationStatusResponse
Retrieves the revocation status for a signed artifact by checking if the signing profile, job, or certificate has been revoked.
539 540 541 542 |
# File 'lib/aws-sdk-signerdata/client.rb', line 539 def get_revocation_status(params = {}, = {}) req = build_request(:get_revocation_status, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
568 569 570 |
# File 'lib/aws-sdk-signerdata/client.rb', line 568 def waiter_names [] end |